<?php

/**
 * @file
 * Provides the Consent Manager administration settings.
 */

/**
 * Consent Manager settings form.
 *
 * @param $form
 * @param $form_state
 *
 * @return array
 */
function consent_manager_settings($form, &$form_state) {
  $config = variable_get('consent_manager');

  $form['consent_manager'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings'),
    '#collapsible' => FALSE,
    '#tree' => TRUE,
  );
  $form['consent_manager']['blocking_mode'] = array(
    '#type' => 'select',
    '#title' => t('Blocking mode'),
    '#options' => array(
      'automatic' => t('Automatic blocking'),
      'semi_automatic' => t('Semi-Automatic blocking'),
    ),
    '#default_value' => isset($config['blocking_mode']) ? $config['blocking_mode'] : 'semi_automatic',
    '#required' => TRUE,
  );
  $form['consent_manager']['cmp_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Id'),
    '#description' => t('If you don\'t yet have an ID, please get in on <a href="@url" target="_blank">www.consentmanager.net</a>', array('@url' => 'https://www.consentmanager.net/client/codes.php')),
    '#default_value' => isset($config['cmp_id']) ? $config['cmp_id'] : '',
    '#min' => 1,
    '#step' => 1,
    '#required' => TRUE,
  );
  $form['consent_manager']['custom_code'] = array(
    '#type' => 'textarea',
    '#title' => t('Custom HTML code'),
    '#description' => t('Additional HTML code: appears before the consent manager integration markup.'),
    '#default_value' =>  isset($config['custom_code']) ? $config['custom_code'] : '',
  );

  return system_settings_form($form);
}

/**
 * Consent Manager settings form validation.
 *
 * @param $form
 * @param $form_state
 */
function consent_manager_settings_validate($form, &$form_state) {
  if (empty($form_state['values']['consent_manager']['cmp_id'])) {
    form_set_error('consent_manager][cmp_id', t('You need to fill the <em>Id</em> value.'));
  }
  else {
    $cmp_id = $form_state['values']['consent_manager']['cmp_id'];
    if ($cmp_id < 1 || $cmp_id != (int) $cmp_id) {
      form_set_error('consent_manager][cmp_id', t('<em>Id</em> value should be positive integer.'));
    }
  }
}
